@@ -89,6 +89,12 @@ def arguments():
     )
     parser.version = __version__
 
+    parser.add_argument(
+        "-V",
+        "--version",
+        action="version",
+        help="""Show version.""",
+    )
     parser.add_argument(
         "source",
         nargs="+",
@@ -188,12 +194,6 @@ def arguments():
         help="""Verbose feedback of all progress to log or console. Optional,
         defaults to warnings and errors only.""",
     )
-    parser.add_argument(
-        "-V",
-        "--version",
-        action="version",
-        help="""Prints atcociftogtfs version and exits.""",
-    )
     parser.add_argument(
         "-s",
         "--school_term",
@@ -250,7 +250,7 @@ def walk(source, processor):
         else:
             status = processor.file(filename=source)
             if status == 0:
-                logging.info("Completed %s", os.path.basename(source))
+                logging.info("Processed %s", os.path.basename(source))
 
     else:
 
